#[tool]Expand description
Derive a Tool implementation from an annotated async function.
See the crate-level documentation for full usage.
#[tool]Derive a Tool implementation from an annotated async function.
See the crate-level documentation for full usage.